@@ -247,7 +247,7 @@ def _add_ext(key, value, events, errors):
 
 class ExtensionKey(object):
 
-    """ This definitely isn't needed, but we keep it around for compatibilty
+    """ This definitely isn't needed, but we keep it around for compatibility
     with xpyb.
     """
 
@@ -297,6 +297,12 @@ class Protobj(object):
             self.bufsize = unpacker.known_max
 
 
+class Buffer(Protobj):
+    def __init__(self, unpacker):
+        Protobj.__init__(self, unpacker)
+        self.buf = unpacker.buf
+
+
 class Struct(Protobj):
     pass
 
@@ -418,6 +424,8 @@ class List(Protobj):
 
         self.bufsize = unpacker.offset - old
 
+        self.raw = bytes(unpacker.buf[old:old + self.bufsize])
+
         assert count is None or count == len(self.list)
 
     def __str__(self):
@@ -452,7 +460,7 @@ class List(Protobj):
         return struct.unpack("<" + "I" * (len(self) // 4), b''.join(self))
 
     def buf(self):
-        return b''.join(self.list)
+        return self.raw
 
     @classmethod
     def synthetic(cls, list=None):
